<?php

namespace Matrimony\Matrimony\Policies;

use Litepie\User\Contracts\UserPolicy;
use Matrimony\Matrimony\Models\Preference;

class PreferencePolicy
{

    /**
     * Determine if the given user can view the preference.
     *
     * @param UserPolicy $user
     * @param Preference $preference
     *
     * @return bool
     */
    public function view(UserPolicy $user, Preference $preference)
    {
        if ($user->canDo('matrimony.preference.view') && $user->isAdmin()) {
            return true;
        }

        return $preference->user_id == user_id() && $preference->user_type == user_type();
    }

    /**
     * Determine if the given user can create a preference.
     *
     * @param UserPolicy $user
     * @param Preference $preference
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('matrimony.preference.create');
    }

    /**
     * Determine if the given user can update the given preference.
     *
     * @param UserPolicy $user
     * @param Preference $preference
     *
     * @return bool
     */
    public function update(UserPolicy $user, Preference $preference)
    {
        if ($user->canDo('matrimony.preference.edit') && $user->isAdmin()) {
            return true;
        }

        return $preference->user_id == user_id() && $preference->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given preference.
     *
     * @param UserPolicy $user
     * @param Preference $preference
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Preference $preference)
    {
        return $preference->user_id == user_id() && $preference->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given preference.
     *
     * @param UserPolicy $user
     * @param Preference $preference
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Preference $preference)
    {
        if ($user->canDo('matrimony.preference.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given preference.
     *
     * @param UserPolicy $user
     * @param Preference $preference
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Preference $preference)
    {
        if ($user->canDo('matrimony.preference.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
