<?php

namespace Matrimony\Matrimony\Providers;

use Illuminate\Support\ServiceProvider;

class MatrimonyServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'matrimony');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'matrimony');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('matrimony.matrimony', function ($app) {
            return $this->app->make('Matrimony\Matrimony\Matrimony');
        });

        // Bind Profile to repository
        $this->app->bind(
            'Matrimony\Matrimony\Interfaces\ProfileRepositoryInterface',
            \Matrimony\Matrimony\Repositories\Eloquent\ProfileRepository::class
        );
        // Bind Preference to repository
        $this->app->bind(
            'Matrimony\Matrimony\Interfaces\PreferenceRepositoryInterface',
            \Matrimony\Matrimony\Repositories\Eloquent\PreferenceRepository::class
        );

        $this->app->register(\Matrimony\Matrimony\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Matrimony\Matrimony\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['matrimony.matrimony'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('matrimony/matrimony.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/matrimony')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/matrimony')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
