<?php

namespace Matrimony\Matrimony\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Matrimony\Matrimony\Models\Matrimony;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Matrimony\Matrimony\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/matrimony/profile/*')) {
            Route::bind('profile', function ($profile) {
                $profilerepo = $this->app->make('Matrimony\Matrimony\Interfaces\ProfileRepositoryInterface');
                return $profilerepo->findorNew($profile);
            });
        }

        if (Request::is('*/matrimony/preference/*')) {
            Route::bind('preference', function ($preference) {
                $preferencerepo = $this->app->make('Matrimony\Matrimony\Interfaces\PreferenceRepositoryInterface');
                return $preferencerepo->findorNew($preference);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {
        if (request()->segment(1) == 'api' || request()->segment(2) == 'api') {
            return;
        }
        
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
            'prefix'     => trans_setlocale(),
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
